Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(76)

Unified Diff: pkg/compiler/lib/src/resolution/resolution_result.dart

Issue 2603263002: Prefix resolution_types with Resolution. (Closed)
Patch Set: Rebased Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/compiler/lib/src/resolution/resolution.dart ('k') | pkg/compiler/lib/src/resolution/scope.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/resolution/resolution_result.dart
diff --git a/pkg/compiler/lib/src/resolution/resolution_result.dart b/pkg/compiler/lib/src/resolution/resolution_result.dart
index 6d13bb0042360e4ba3b366e992e30a729bafb212..fd7576f8267635ca57f24d4d662fd51674f9763a 100644
--- a/pkg/compiler/lib/src/resolution/resolution_result.dart
+++ b/pkg/compiler/lib/src/resolution/resolution_result.dart
@@ -32,7 +32,7 @@ abstract class ResolutionResult {
ResultKind get kind;
Node get node => null;
Element get element => null;
- DartType get type => null;
+ ResolutionDartType get type => null;
ConstantExpression get constant => null;
bool get isConstant => false;
}
@@ -67,9 +67,10 @@ class ElementResult extends ResolutionResult {
String toString() => 'ElementResult($element)';
}
/// The result for the resolution of a node that points to an [DartType].
class TypeResult extends ResolutionResult {
- final DartType type;
+ final ResolutionDartType type;
TypeResult(this.type) {
assert(type != null);
« no previous file with comments | « pkg/compiler/lib/src/resolution/resolution.dart ('k') | pkg/compiler/lib/src/resolution/scope.dart » ('j') | no next file with comments »
@@ -67,9 +67,10 @@ class ElementResult extends ResolutionResult {
String toString() => 'ElementResult($element)';
}
-/// The result for the resolution of a node that points to an [DartType].
+/// The result for the resolution of a node that points to an
+/// [ResolutionDartType].
class TypeResult extends ResolutionResult {

Powered by Google App Engine
This is Rietveld 408576698